'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

(function (Direction) {
  Direction["X"] = "x";
  Direction["Y"] = "y";
})(exports.Direction || (exports.Direction = {})); // get the relative distance from destination


var getRelativeDistance = function getRelativeDistance(target, parent, attrMap) {
  if (!target) return 0;
  if (typeof target === 'number') return target;

  if (typeof target === 'string') {
    var elm = document.querySelector(target);
    var dis = elm.getBoundingClientRect()[attrMap.leftTop] - parent.getBoundingClientRect()[attrMap.leftTop];
    return dis;
  }

  return 0;
};

var useSmoothScroll = function useSmoothScroll(_ref) {
  var ref = _ref.ref,
      _ref$speed = _ref.speed,
      speed = _ref$speed === void 0 ? 40 : _ref$speed,
      _ref$direction = _ref.direction,
      direction = _ref$direction === void 0 ? exports.Direction.Y : _ref$direction,
      _ref$threshold = _ref.threshold,
      threshold = _ref$threshold === void 0 ? 1 : _ref$threshold;
  var attrMap = {
    leftTop: exports.Direction.X === direction ? 'left' : 'top',
    offsetLeftTop: exports.Direction.X === direction ? 'offsetLeft' : 'offsetTop',
    offsetWidthHeight: exports.Direction.X === direction ? 'offsetWidth' : 'offsetHeight',
    scrollLeftTop: exports.Direction.X === direction ? 'scrollLeft' : 'scrollTop',
    scrollWidthHeight: exports.Direction.X === direction ? 'scrollWidth' : 'scrollHeight',
    clientWidthHeight: exports.Direction.X === direction ? 'clientWidth' : 'clientHeight'
  };

  var scrollTo = function scrollTo(target) {
    var elm = ref.current;
    if (!elm) return;
    var initScrollLeftTop = elm[attrMap.scrollLeftTop];
    var distance = getRelativeDistance(target, elm, attrMap);
    if (distance === 0) return;

    if (elm.scrollTo && !speed) {
      var _elm$scrollTo;

      elm.scrollTo((_elm$scrollTo = {}, _elm$scrollTo[attrMap.leftTop] = elm[attrMap.scrollLeftTop] + distance, _elm$scrollTo.behavior = 'smooth', _elm$scrollTo));
    } else {
      var _speed = speed;

      var cb = function cb() {
        // scroll to edge
        if (distance > 0 ? elm[attrMap.scrollLeftTop] + elm[attrMap.clientWidthHeight] >= elm[attrMap.scrollWidthHeight] : elm[attrMap.scrollLeftTop] === 0) {
          return;
        }

        var gone = function gone() {
          return Math.abs(elm[attrMap.scrollLeftTop] - initScrollLeftTop);
        };

        if (Math.abs(distance) - gone() < speed) {
          _speed = Math.abs(distance) - gone();
        } // 每个帧，通常为1/60s内滚动条移动的距离


        elm[attrMap.scrollLeftTop] += _speed * (distance > 0 ? 1 : -1); // reach destination, threshold defaults to 1

        if (Math.abs(gone() - Math.abs(distance)) < threshold) {
          return;
        }

        requestAnimationFrame(cb);
      };

      requestAnimationFrame(cb);
    }
  };

  return {
    scrollTo: scrollTo
  };
};

exports.default = useSmoothScroll;
exports.useSmoothScroll = useSmoothScroll;
//# sourceMappingURL=react-smooth-scroll-hook.cjs.development.js.map
